==> composio_core-0.5.6.tar.gz: composio_core-0.5.6/composio/tools/local/codegrep/actions/grep_code.py <==
from pathlib import Path
from typing import List, Optional, Type

from pydantic import BaseModel, Field

from composio.tools.base.local import LocalAction
from composio.tools.local.base.utils.grep_utils import grep_util


class CodeSearchRequest(BaseModel):
    query: str = Field(
        ...,
        description="""The search pattern or regular expression to find in the codebase.
Use this to locate specific code constructs, function definitions,
variable names, or text patterns.""",
        examples=["def main(", "TODO:", "import numpy"],
    )
    code_directory: str = Field(
        default=str(Path.home()),
        description="""The code directory to start the search from.
This should be the top-level folder of your project or codebase.
If not specified, the search will start from the user's home directory.
""",
        examples=["/path/to/project", "/home/user/workspace/my-app"],
    )
    file_paths: List[str] = Field(
        default=None,
        description="""A list of specific file paths to search within.
Use this when you want to limit the search to particular files or subdirectories.
If not provided, the search will cover all files under the root_directory.""",
        examples=[
            ["/path/to/project/src/main.py", "/path/to/project/tests/test_main.py"],
            ["app/models.py", "app/views.py", "app/controllers.py"],
        ],
    )


class SearchResult(BaseModel):
    file_path: str
    matched_content: str


class CodeSearchResponse(BaseModel):
    matches: List[SearchResult] = Field(
        ...,
        description="A list of search results, each containing the file path and the matched content.",
    )
    error: Optional[str] = Field(
        default=None,
        description="An error message describing any issues encountered during the search process. This field is None if the search was successful.",
    )


class SearchCodebase(LocalAction[CodeSearchRequest, CodeSearchResponse]):
    """
    Performs an advanced search across a codebase using regex patterns, similar to the grep command but optimized for large-scale software projects.

    This action is ideal for when you need to quickly locate specific code patterns, function definitions, or text within a large codebase. It's particularly useful for:
    - Finding all occurrences of a particular function or class
    - Locating TODO comments or specific error handling patterns
    - Identifying usage of certain libraries or API calls
    - Searching for potential security vulnerabilities or code smells

    The search is performed efficiently and can handle large codebases by leveraging optimized search algorithms and respecting version control ignore files.

    Example usage: # Searches for function definitions starting with 'process_data'
    search_request =
    query="def process_data(",
    code_directory="/project",

    This action provides a powerful tool for code analysis, refactoring assistance, and codebase exploration tasks.
    """

    display_name = "Advanced Codebase Search"
    _request_schema: Type[CodeSearchRequest] = CodeSearchRequest
    _response_schema: Type[CodeSearchResponse] = CodeSearchResponse
    _tags = ["search", "code-analysis"]
    _tool_name = "codegrep"

    def execute(
        self, request_data: CodeSearchRequest, metadata: dict = {}
    ) -> CodeSearchResponse:
        try:
            search_paths = request_data.file_paths or [request_data.code_directory]

            grep_results = grep_util(
                pattern=request_data.query, filenames=search_paths, no_gitignore=False
            )
            print("Grep results: ", grep_results)
            formatted_results = [
                SearchResult(
                    file_path=result["filename"], matched_content=result["matches"]
                )
                for result in grep_results
            ]

            return CodeSearchResponse(matches=formatted_results)
        except Exception as e:
            error_message = f"An error occurred during the codebase search: {str(e)}"
            print(error_message)
            return CodeSearchResponse(matches=[], error=error_message)

==> composio_core-0.5.21.tar.gz: composio_core-0.5.21/composio/tools/local/codegrep/actions/grep_code.py <==
from pathlib import Path
from typing import List, Optional

from pydantic import BaseModel, Field

from composio.tools.base.local import LocalAction
from composio.tools.local.base.utils.grep_utils import grep_util


class CodeSearchRequest(BaseModel):
    query: str = Field(
        ...,
        description="""The search pattern or regular expression to find in the codebase.
Use this to locate specific code constructs, function definitions,
variable names, or text patterns.""",
        examples=["def main(", "TODO:", "import numpy"],
    )
    code_directory: str = Field(
        default=str(Path.home()),
        description="""The code directory to start the search from.
This should be the top-level folder of your project or codebase.
If not specified, the search will start from the user's home directory.
""",
        examples=["/path/to/project", "/home/user/workspace/my-app"],
    )
    file_paths: List[str] = Field(
        default=None,
        description="""A list of specific file paths to search within.
Use this when you want to limit the search to particular files or subdirectories.
If not provided, the search will cover all files under the root_directory.""",
        examples=[
            ["/path/to/project/src/main.py", "/path/to/project/tests/test_main.py"],
            ["app/models.py", "app/views.py", "app/controllers.py"],
        ],
    )


class SearchResult(BaseModel):
    file_path: str
    matched_content: str


class CodeSearchResponse(BaseModel):
    matches: List[SearchResult] = Field(
        ...,
        description="A list of search results, each containing the file path and the matched content.",
    )
    error: Optional[str] = Field(
        default=None,
        description="An error message describing any issues encountered during the search process. This field is None if the search was successful.",
    )


class SearchCodebase(LocalAction[CodeSearchRequest, CodeSearchResponse]):
    """
    Performs an advanced search across a codebase using regex patterns, similar to the grep command but optimized for large-scale software projects.

    This action is ideal for when you need to quickly locate specific code patterns, function definitions, or text within a large codebase. It's particularly useful for:
    - Finding all occurrences of a particular function or class
    - Locating TODO comments or specific error handling patterns
    - Identifying usage of certain libraries or API calls
    - Searching for potential security vulnerabilities or code smells

    The search is performed efficiently and can handle large codebases by leveraging optimized search algorithms and respecting version control ignore files.

    Example usage: # Searches for function definitions starting with 'process_data'
    search_request =
    query="def process_data(",
    code_directory="/project",

    This action provides a powerful tool for code analysis, refactoring assistance, and codebase exploration tasks.
    """

    display_name = "Advanced Codebase Search"
    _tags = ["search", "code-analysis"]

    def execute(self, request: CodeSearchRequest, metadata: dict) -> CodeSearchResponse:
        search_paths = request.file_paths or [request.code_directory]
        grep_results = grep_util(
            pattern=request.query,
            filenames=search_paths,
            no_gitignore=False,
        )
        formatted_results = [
            SearchResult(
                file_path=result["filename"], matched_content=result["matches"]
            )
            for result in grep_results
        ]
        return CodeSearchResponse(matches=formatted_results)
